[PATCH v3 12/26] staging: most: core: rename function

Christian Gromm christian.gromm at microchip.com
Mon Oct 16 08:46:19 UTC 2017


The core module used to have two functions to find a certain
channel. One by name and one by interface. Since no channel is
searched by its interface name anymore the by_name suffix is
rendered redundant. This patch renames the function accordingly.

Signed-off-by: Christian Gromm <christian.gromm at microchip.com>
---
v2: fix patch numeration
v3: - add cover letter
    - create patches with -M switch to make file movement visible

 drivers/staging/most/core.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/most/core.c b/drivers/staging/most/core.c
index 3cf72a1..a68f0cc 100644
--- a/drivers/staging/most/core.c
+++ b/drivers/staging/most/core.c
@@ -647,13 +647,13 @@ static int split_string(char *buf, char **a, char **b, char **c, char **d)
 }
 
 /**
  * get_channel_by_name - get pointer to channel object
  * @mdev: name of the device instance
  * @mdev_ch: name of the respective channel
  *
  * This retrieves the pointer to a channel object.
  */
-static struct most_channel *get_channel_by_name(char *mdev, char *mdev_ch)
+static struct most_channel *get_channel(char *mdev, char *mdev_ch)
 {
 	struct most_channel *c, *tmp;
 	struct most_inst_obj *i, *i_tmp;
@@ -752,7 +752,7 @@ static ssize_t add_link_store(struct device_driver *drv,
 		aim_param = devnod_buf;
 	}
 
-	c = get_channel_by_name(mdev, mdev_ch);
+	c = get_channel(mdev, mdev_ch);
 	if (IS_ERR(c))
 		return -ENODEV;
 
@@ -791,7 +791,7 @@ static ssize_t remove_link_store(struct device_driver *drv,
 	if (ret)
 		return ret;
 	aim = match_module(aim_name);
-	c = get_channel_by_name(mdev, mdev_ch);
+	c = get_channel(mdev, mdev_ch);
 	if (IS_ERR(c))
 		return -ENODEV;
 
@@ -647,13 +647,13 @@ static int split_string(char *buf, char **a, char **b, char **c, char **d)
 
 /**
- * get_channel_by_name - get pointer to channel object
+ * get_channel - get pointer to channel object
  * @mdev: name of the device instance
  * @mdev_ch: name of the respective channel
-- 
1.9.1



More information about the devel mailing list